Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2010-10-25 13:43:11 +0000
committerStijn Buys <ingar@osirion.org>2010-10-25 13:43:11 +0000
commit5189168482f32d8aac630cde27fc0999e70ed57b (patch)
treed96dc388274ff13d594264ed5eeb2f9cce79370d /src/game/base/shipmodel.h
parent787002ec11bf41bba01b899c53a38830768fc260 (diff)
renamed ship torque_force to turn_force, added ship roll_force
Diffstat (limited to 'src/game/base/shipmodel.h')
-rw-r--r--src/game/base/shipmodel.h25
1 files changed, 18 insertions, 7 deletions
diff --git a/src/game/base/shipmodel.h b/src/game/base/shipmodel.h
index e90c59e..c7aa2ba 100644
--- a/src/game/base/shipmodel.h
+++ b/src/game/base/shipmodel.h
@@ -57,9 +57,14 @@ public:
return shipmodel_strafe_force;
}
- /// default torque force
- inline const float torque_force() const {
- return shipmodel_torque_force;
+ /// default turn force
+ inline const float turn_force() const {
+ return shipmodel_turn_force;
+ }
+
+ /// default turn force
+ inline const float roll_force() const {
+ return shipmodel_roll_force;
}
/// maximum thrust speed
@@ -95,11 +100,16 @@ public:
shipmodel_strafe_force = strafe;
}
- /// set torque force
- inline void set_torque_force(const float torque) {
- shipmodel_torque_force = torque;
+ /// set turn force
+ inline void set_turn_force(const float turn) {
+ shipmodel_turn_force = turn;
}
+ /// set roll force
+ inline void set_roll_force(const float roll) {
+ shipmodel_roll_force = roll;
+ }
+
/// set maximum speed
inline void set_maxspeed(const float maxspeed) {
shipmodel_maxspeed = maxspeed;
@@ -141,7 +151,8 @@ private:
float shipmodel_impulse_force;
float shipmodel_thrust_force;
float shipmodel_strafe_force;
- float shipmodel_torque_force;
+ float shipmodel_turn_force;
+ float shipmodel_roll_force;
float shipmodel_maxspeed;
float shipmodel_maxcargo;